# eu_common_space_transposed.r
#
#  Remove all objects just to be safe
#
rm(list=ls(all=TRUE))
#
library(foreign)
library(basicspace)
#
europe <- read.dta("c:/Files/Dropbox/Spatial R Book/EU/March24/eu_common_space_lr_transposed_min_8.dta")
#
experts <- europe[,1]
#
#
parties <- c("a","b","c","102","103","104","105","106","107","108","109","110","112","113","114","115","116",
	"201","202","203","206","211","213","215","218","301","302","303","304","306","308","501","502","504",
	"505","506","507","511","513","517","520","523","1001","1002","1003","1004","1005","1014","1016","1017",
	"1018","1019","1101","1102","1104","1105","1106","1107","1108","1109","1301","1302","1303","1304","1307",
	"1401","1402","1403","1404","1405","1406","1408","1409","1601","1602","1603","1604","1605","1606","1607",
	"1609","1610","2001","2002","2003","2004","2007","2008","2009","2010","2101","2102","2103","2104","2107",
	"2109","2110","2201","2202","2203","2204","2206","2207","2301","2302","2303","2304","2307","2308","2309",
	"2601","2603","2604","2605","2606","2607","2611","2612")
#
#
sub.europe <- europe[,-1]
#
rownames(sub.europe) <- experts
colnames(sub.europe) <- parties
#
#
nrow <- length(sub.europe[,1])
ncol <- length(sub.europe[1,])
#
#
valid <- rep(-999,ncol)
#
for (i in 1:ncol) {
valid[i] <-  length(sub.europe[,i][sub.europe[,i]!=-999])
}
#
means <- rep(-999,ncol)
#
#
for (i in 1:ncol) {
means[i] <-  mean(sub.europe[,i][sub.europe[,i]!=-999])
}
#
#
#
sds <- rep(-999,ncol)
#
for (i in 1:ncol) {
sds[i] <-  sd(sub.europe[,i][sub.europe[,i]!=-999])
}
#
#
# Dataset has experts are on rows, parties (stimuli) on columns
#
#
sub.europe <- as.matrix(sub.europe)
#
mode(sub.europe) <- c("numeric")
#
result <- blackbox_transpose(sub.europe,missing=-999,dims=3,minscale=5,verbose=TRUE)
#
#
# Two dimensional coordinates 
#
x <- result$stimuli[[2]][,2]
y <- result$stimuli[[2]][,3]
#
# Flip first dimension
#
x <- (-1*x)
#
onedim <- result$fits[1,3]
twodim <- result$fits[2,3]
#
#
# Can use "fix(summary)" for quick visual inspection
#
summary <- cbind(parties,valid,means,x,y)
#
#
# Plot leftist parties red, rightist parties blue, moderate parties green
#
plot(x,y,type="n",asp=1,
       main="",
       xlab="",
       ylab="")
#
# Main title
mtext("European Party Placement Data\n(Left = red, Moderate = green, Right = blue)",side=3,line=1.25,cex=1.2,font=2)
# x-axis title
mtext(paste("First Dimension Fit = ",round(onedim,2)),side=1,line=2.5,cex=1.2)
# y-axis title
mtext(paste("Second Dimension Fit = ",round(twodim,2)),side=2,line=2.5,cex=1.2)
#
#
points(x[means>=7],y[means>=7],pch=16,col="blue")
points(x[means>3 & means<7],y[means>3 & means<7],pch=16,col="green")
points(x[means<=3],y[means<=3],pch=16,col="red")
#
# Plot the vignette parties
#
points(x[1],y[1],pch='A',col="black",font=2,cex=2.0)
points(x[2],y[2],pch='B',col="black",font=2,cex=2.0)
points(x[3],y[3],pch='C',col="black",font=2,cex=2.0)
#
#
# Plots of first and second dimension coordinates against mean placement
# 
#
windows()
par(mfrow=c(1,2))
#
plot(x,means,type="n",
       main="",
       xlab="",
       ylab="",
       xlim=c(-0.25,0.25),ylim=c(0.0,10.0),cex=1.2,font=2)
#
# Main title
mtext("First Dimension Basic Space Score vs. Mean Placement\n(Left = red, Moderate = green, Right = blue)",side=3,line=1.25,cex=1.2,font=2)
# x-axis title
mtext("First Dimension Coordinate",side=1,line=2.5,cex=1.2)
# y-axis title
mtext("Mean Party Placement",side=2,line=2.5,cex=1.2)
#
#
points(x[means>=7],means[means>=7],pch=16,col="blue")
points(x[means>3 & means<7],means[means>3 & means<7],pch=16,col="green")
points(x[means<=3],means[means<=3],pch=16,col="red")
#
lines(lowess(means~x),lwd=2)
#
#
#
plot(y,means,type="n",
       main="",
       xlab="",
       ylab="",
       xlim=c(-0.4,0.4),ylim=c(0.0,10.0),cex=1.2,font=2)
#
# Main title
mtext("Second Dimension Basic Space Score vs. Mean Placement\n(Left = red, Moderate = green, Right = blue)",side=3,line=1.25,cex=1.2,font=2)
# x-axis title
mtext("Second Dimension Coordinate",side=1,line=2.5,cex=1.2)
# y-axis title
mtext("Mean Party Placement",side=2,line=2.5,cex=1.2)
#
#
points(y[means>=7],means[means>=7],pch=16,col="blue")
points(y[means>3 & means<7],means[means>3 & means<7],pch=16,col="green")
points(y[means<=3],means[means<=3],pch=16,col="red")
#
lines(lowess(means~y),lwd=2)
#
#